@@ -7,6 +7,7 @@ import numpy as np
 import numpy.ma as ma
 import neuroml
 
+
 class ArrayMorphology(neuroml.Morphology):
     """Core of the array-based object model backend.
 
@@ -149,8 +150,8 @@ class ArrayMorphology(neuroml.Morphology):
         return self.connectivity[index]
 
     def vertex(self,index):
-       """Return vertex corresponding to index in morphology"""
-       return self.vertices[index]
+        """Return vertex corresponding to index in morphology"""
+        return self.vertices[index]
 
     def __len__(self):
         return len(self.connectivity)
@@ -186,8 +187,6 @@ class ArrayMorphology(neuroml.Morphology):
         return morphology
 
     def segment_from_vertex_index(self,index):
-        print "index:"
-        print index
         parent_index = self.connectivity[index]
         
         node_x = self.vertices[index][0]
@@ -257,7 +256,7 @@ class SegmentList(object):
         if num_segments < 0:
             num_segments = 0
 
-        return num_segments
+        return int(num_segments)
 
     def __iadd__(self,segment_list):
         for segment in segment_list:
