@@ -7,6 +7,9 @@ from lxml import objectify
 import re
 from config import variables
 import csv
+import sys
+
+sys.setrecursionlimit(10000)
 
 def remove_curlies(string):
     return re.sub("{.*}","",string)
@@ -57,7 +60,7 @@ def pluralize(noun):
 def _node_to_python(node):
 
     pluralize_flag = 'maxOccurs' in node.attrib
-
+    
     for attribute in node.attrib:
         nml_attribute = node.attrib.pop(attribute)
         if nml_attribute[0].islower():
@@ -68,7 +71,17 @@ def _node_to_python(node):
 
 filename = variables['schema_name']
 
-doc = objectify.parse(filename)
+import StringIO
+import process_includes
+
+outfile = StringIO.StringIO()
+infile = open(filename, 'r')
+
+process_includes.process_include_files(infile, outfile,
+        inpath=filename)
+infile.close()
+outfile.seek(0)
+doc = objectify.parse(outfile)
 root = doc.getroot()
 queue = [root]
 
@@ -93,6 +106,10 @@ NameTable['ionChannelHH'] = 'ion_channel_hh'
 NameTable['gateHHrates']  = 'gate_hh_rates'
 NameTable['gateHHtauInf'] = 'gate_hh_tau_infs'
 
+NameTable['ionChannel'] = 'ion_channel'
+NameTable['ionChannelHH'] = 'ion_channel_hhs'
+
+
 
 NameTable['basePyNNCell'] = 'basePyNNCell'
 NameTable['basePyNNIaFCell'] = 'basePyNNIaFCell'
@@ -108,6 +125,8 @@ NameTable['e_rev_K'] = 'e_rev_K'
 NameTable['gbar_K'] = 'gbar_K'
 NameTable['gbar_Na'] = 'gbar_Na'
 
+NameTable['delta_T'] = 'delta_T'
+
 NameTable['IF_curr_alpha'] = 'IF_curr_alpha'
 NameTable['IF_curr_exp'] = 'IF_curr_exp'
 NameTable['IF_cond_alpha'] = 'IF_cond_alpha'
@@ -118,7 +137,7 @@ NameTable['intracellularProperties'] = 'intracellular_properties'
 NameTable['biophysicalProperties'] = 'biophysical_properties'
 
 print("NameTable is as follows:")
-print NameTable
+print(NameTable)
 
 print("Saving NameTable to csv file")
 writer = csv.writer(open('name_table.csv', 'wb'))
