@@ -1,11 +1,9 @@
 import neuroml
-import numpy as np
-import tables
-from jsonpickle import encode as json_encode
+
 
 class NeuroMLWriter(object):
     @classmethod
-    def write(cls,nmldoc,file):
+    def write(cls,nmldoc,file,close=True):
         """
         Writes from NeuroMLDocument to nml file
         in future can implement from other types
@@ -17,23 +15,101 @@ class NeuroMLWriter(object):
 
         #TODO: this should be extracted from the schema:
         namespacedef = 'xmlns="http://www.neuroml.org/schema/neuroml2" '
-        namespacedef += ' xmlns:xi="http://www.w3.org/2001/XInclude"'
         namespacedef += ' xmlns:xs="http://www.w3.org/2001/XMLSchema"'
         namespacedef += ' xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"'
-        namespacedef += ' xsi:schemaLocation="http://www.w3.org/2001/XMLSchema"'
+        namespacedef += ' xsi:schemaLocation="http://www.neuroml.org/schema/neuroml2 https://raw.github.com/NeuroML/NeuroML2/development/Schemas/NeuroML2/NeuroML_%s.xsd"'%neuroml.current_neuroml_version
 
         nmldoc.export(file,0,name_="neuroml",
                       namespacedef_=namespacedef) #name_ param to ensure root element named correctly - generateDS limitation
+                      
+        if close:
+            file.close()
 
+
+class NeuroMLHdf5Writer(object):
+    
+        
+    @classmethod
+    def write(cls,nml_doc,h5_file_name,embed_xml=True,compress=True):
+        
+        import tables
+        FILTERS = tables.Filters(complib='zlib', complevel=5) if compress else tables.Filters()
+        h5file = tables.open_file(h5_file_name, mode = "w", title = nml_doc.id, filters=FILTERS)
+        
+        rootGroup = h5file.create_group("/", 'neuroml', 'Root NeuroML group')
+        
+        rootGroup._f_setattr("id", nml_doc.id)
+        rootGroup._f_setattr("notes", nml_doc.notes)
+        
+        for network in nml_doc.networks:
+
+            network.exportHdf5(h5file, rootGroup)
+            
+        if embed_xml:
+            
+            networks = []
+            for n in nml_doc.networks:
+                networks.append(n)
+            
+            nml_doc.networks = []
+            
+            try:
+                import StringIO
+                sf = StringIO.StringIO()
+            except:
+                import io
+                sf = io.StringIO()
+            
+            NeuroMLWriter.write(nml_doc,sf,close=False)
+            
+            nml2 = sf.getvalue()
+            
+            rootGroup._f_setattr("neuroml_top_level", nml2)
+            
+
+            # Put back into previous form...
+            for n in networks:
+                nml_doc.networks.append(n)
+            
+        h5file.close()  # Close (and flush) the file
+        
+        
+    @classmethod
+    def write_xml_and_hdf5(cls,nml_doc0,xml_file_name,h5_file_name):
+        
+        nml_doc_hdf5 = neuroml.NeuroMLDocument(nml_doc0.id)
+        
+        for n in nml_doc0.networks:
+            nml_doc_hdf5.networks.append(n)
+            
+        nml_doc0.networks = []
+        
+        nml_doc0.includes.append(neuroml.IncludeType(h5_file_name)) 
+        
+        NeuroMLWriter.write(nml_doc0,xml_file_name)
+        
+        NeuroMLHdf5Writer.write(nml_doc_hdf5,h5_file_name,embed_xml=False)
+        
+        # Put back into previous form...
+        for n in nml_doc_hdf5.networks:
+            nml_doc0.networks.append(n)
+        for inc in nml_doc0.includes:
+            if inc.href == h5_file_name:
+                nml_doc0.includes.remove(inc)
+        
+        
+        
 class JSONWriter(object):
     """
     Write a NeuroMLDocument to JSON, particularly useful
     when dealing with lots of ArrayMorphs.
     """
 
+    
     @classmethod
     def __encode_as_json(cls,neuroml_document):
         neuroml_document = cls.__sanitize_doc(neuroml_document)
+        from jsonpickle import encode as json_encode
         encoded = json_encode(neuroml_document)
         return encoded
     
@@ -57,7 +133,8 @@ class JSONWriter(object):
     @classmethod
     def __file_handle(file):
         if isinstance(cls,file,str):
-            fileh = tables.openFile(filepath, mode = "w")
+            import tables
+            fileh = tables.open_file(filepath, mode = "w")
 
             
     @classmethod    
@@ -74,6 +151,7 @@ class JSONWriter(object):
             raise NotImplementedError("Currently you can only serialize NeuroMLDocument type in JSON format")
 
         fileh.write(encoded)
+        fileh.close()
 
     @classmethod
     def write_to_mongodb(cls,neuroml_document,db,host=None,port=None,id=None):
@@ -121,16 +199,16 @@ class ArrayMorphWriter(object):
             morphology_name = array_morph.id
 
         if cell_id == None:
-            morphology_group = fileh.createGroup(root, morphology_name)
+            morphology_group = fileh.create_group(root, morphology_name)
             hierarchy_prefix = "/" + morphology_name
         else:
-            cell_group = fileh.createGroup(root, cell_id)
-            morphology_group = fileh.createGroup(cell_group, morphology_name)
+            cell_group = fileh.create_group(root, cell_id)
+            morphology_group = fileh.create_group(cell_group, morphology_name)
             hierarchy_prefix = '/' + cell_id + '/' + morphology_name
 
-        vertices_array = fileh.createArray(hierarchy_prefix, "vertices", vertices)
-        connectivity_array = fileh.createArray(hierarchy_prefix, "connectivity", connectivity)
-        physical_mask_array = fileh.createArray(hierarchy_prefix, "physical_mask", physical_mask)
+        vertices_array = fileh.create_array(hierarchy_prefix, "vertices", vertices)
+        connectivity_array = fileh.create_array(hierarchy_prefix, "connectivity", connectivity)
+        physical_mask_array = fileh.create_array(hierarchy_prefix, "physical_mask", physical_mask)
 
     @classmethod
     def __write_neuroml_document(cls,document,fileh):
@@ -157,7 +235,8 @@ class ArrayMorphWriter(object):
     @classmethod
     def write(cls,data,filepath):
 
-        fileh = tables.openFile(filepath, mode = "w")
+        import tables
+        fileh = tables.open_file(filepath, mode = "w")
         
         #Now instead we should go through a document/cell/morphology
         #hierarchy - this kind of tree traversal should be done recursively
